==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/de.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "individuell",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "Erforderlich",
    "Optional" : "Optional",
    "Does not attend" : "nicht teilnehmen",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bist in einer unbekannten Zeitzone ({tz}), auf UTC wird geändert",
    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
    "New event" : "Neue Veranstaltung",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholen",
    "When shared show full event" : "wenn geteilt, zeige das ganze Ereignis",
    "When shared show only busy" : "wenn geteilt, zeige nur den Status beschäftigt",
    "When shared hide this event" : "wenn geteilt, wird das Ereignis verborgen",
    "Please add a title!" : "Bitte gib einen Titel an!",
    "Please select a calendar!" : "Bitte wähle einen Kalender aus!",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "jeden Tag",
    "Every week" : "jede Woche",
    "Every month" : "jeden Monat",
    "Every year" : "jedes Jahr",
    "never" : "niemals",
    "after" : "nach",
    "At time of event" : "Zum Zeitpunkt der Veranstaltung",
    "5 minutes before" : "vor 5 Minuten",
    "10 minutes before" : "vor 10 Minuten",
    "15 minutes before" : "vor 15 Minuten",
    "30 minutes before" : "vor 30 Minuten",
    "1 hour before" : "vor 1 Stunde",
    "2 hours before" : "vor 2 Stunden",
    "Custom" : "benutzerdefiniert",
    "Audio" : "Audio",
    "E Mail" : "E-Mail",
    "Pop up" : "Pop-up",
    "sec" : "sek",
    "min" : "Min",
    "hours" : "Stunden",
    "days" : "Tagen",
    "week" : "Woche",
    "before" : "vor",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of uknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt",
    "Week {number} of {year}" : "Woche {number} von {year}",
    "Successfully imported" : "Erfolgreich importiert",
    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
    "Partially imported, {n} failures" : "Teilweise importiert , {n} Fehler",
    "Audio alarm" : "Akustischer Alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn der Veranstaltung",
    "{type} {time} before the event ends" : "{type} {time} vor Ende der Veranstaltung",
    "{type} {time} after the event starts" : "{type} {time} nachdem die Veranstaltung beginnt",
    "{type} {time} after the event ends" : "{type} {time} nachdem die Veranstaltung endet",
    "{type} at the event's start" : "{type} zu Beginn der Veranstaltung",
    "{type} at the event's end" : "{type} am Ende der Veranstaltung",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Title of the Event" : "Titel",
    "starts" : "Beginn",
    "ends" : "Ende",
    "All day Event" : "Ganztägiges Ereignis",
    "Location" : "Ort",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr ...",
    "Create" : "Erstellen",
    "Update" : "Aktualisieren",
    "Close" : "Schließen",
    "Description" : "Beschreibung",
    "Export" : "Exportieren",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Durch einen vorgeschalteten Fehler, ist der Kalender zur Zeit nicht in der Lage eine Unterstützung für die Asset Pipeline -Funktion zur Verfügung zu stellen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktiere deinen Administrator und bitte ihn, die \"asset-pipeline.enabled\" Konfiguration zu deaktivieren.",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Share Calendar" : "Kalender freigeben",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "CalDAV" : "CalDAV",
    "group" : "Gruppe",
    "New Calendar" : "Neuer Kalender",
    "Subscriptions" : "Abonnements",
    "New Subscription" : "neues Abonnement",
    "Url" : "Url",
    "Edit event" : "Veranstaltung bearbeiten",
    "Delete Event" : "Veranstaltung löschen",
    "Save Event" : "Veranstaltung speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Add" : "Hinzufügen",
    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte geben Sie Ihre E-Mail-Adresse in den Einstellungen an um Teilnehmer hinzuzufügen.",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Termins wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Updates hinzugefügt.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "Wiederhole immer ...",
    "end repeat ..." : "Wiederholung beenden ...",
    "times" : "Zeiten",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Import abgebrochen",
    "Analyzing calendar" : "Kalender analysieren",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält Objekte, die nicht mit dem ausgewählten Kalender kompatibel sind",
    "New calendar" : "Neuer Kalender",
    "Import scheduled" : "Import geplant",
    "Settings" : "Einstellungen",
    "Import calendar" : "Kalender importieren",
    "No Calendars selected for import" : "Es wurde keine Kalenderdatei für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-Adresse"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/de.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "individuell",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Unbekannt",
    "Required" : "Erforderlich",
    "Optional" : "Optional",
    "Does not attend" : "nicht teilnehmen",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bist in einer unbekannten Zeitzone ({tz}), auf UTC wird geändert",
    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
    "New event" : "Neue Veranstaltung",
    "Attendees" : "Teilnehmer",
    "Reminders" : "Erinnerungen",
    "Repeating" : "Wiederholen",
    "When shared show full event" : "wenn geteilt, zeige das ganze Ereignis",
    "When shared show only busy" : "wenn geteilt, zeige nur den Status beschäftigt",
    "When shared hide this event" : "wenn geteilt, wird das Ereignis verborgen",
    "Please add a title!" : "Bitte gib einen Titel an!",
    "Please select a calendar!" : "Bitte wähle einen Kalender aus!",
    "Global" : "Global",
    "None" : "Keine",
    "Every day" : "jeden Tag",
    "Every week" : "jede Woche",
    "Every month" : "jeden Monat",
    "Every year" : "jedes Jahr",
    "never" : "niemals",
    "after" : "nach",
    "At time of event" : "Zum Zeitpunkt der Veranstaltung",
    "5 minutes before" : "vor 5 Minuten",
    "10 minutes before" : "vor 10 Minuten",
    "15 minutes before" : "vor 15 Minuten",
    "30 minutes before" : "vor 30 Minuten",
    "1 hour before" : "vor 1 Stunde",
    "2 hours before" : "vor 2 Stunden",
    "Custom" : "benutzerdefiniert",
    "Audio" : "Audio",
    "E Mail" : "E-Mail",
    "Pop up" : "Pop-up",
    "sec" : "sek",
    "min" : "Min",
    "hours" : "Stunden",
    "days" : "Tagen",
    "week" : "Woche",
    "before" : "vor",
    "start" : "Start",
    "end" : "Ende",
    "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
    "Week {number} of {year}" : "Woche {number} von {year}",
    "Successfully imported" : "Erfolgreich importiert",
    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
    "Partially imported, {n} failures" : "Teilweise importiert , {n} Fehler",
    "Audio alarm" : "Akustischer Alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-Mail",
    "{type} {time} before the event starts" : "{type} {time} vor Beginn der Veranstaltung",
    "{type} {time} before the event ends" : "{type} {time} vor Ende der Veranstaltung",
    "{type} {time} after the event starts" : "{type} {time} nachdem die Veranstaltung beginnt",
    "{type} {time} after the event ends" : "{type} {time} nachdem die Veranstaltung endet",
    "{type} at the event's start" : "{type} zu Beginn der Veranstaltung",
    "{type} at the event's end" : "{type} am Ende der Veranstaltung",
    "{type} at {time}" : "{type} um {time}",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Title of the Event" : "Titel",
    "starts" : "Beginn",
    "ends" : "Ende",
    "All day Event" : "Ganztägiges Ereignis",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "More ..." : "Mehr ...",
    "Create" : "Erstellen",
    "Update" : "Aktualisieren",
    "Close" : "Schließen",
    "Location" : "Ort",
    "Description" : "Beschreibung",
    "Export" : "Exportieren",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Durch einen vorgeschalteten Fehler, ist der Kalender zur Zeit nicht in der Lage eine Unterstützung für die Asset Pipeline -Funktion zur Verfügung zu stellen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktiere deinen Administrator und bitte ihn, die \"asset-pipeline.enabled\" Konfiguration zu deaktivieren.",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Today" : "Heute",
    "Share Calendar" : "Kalender freigeben",
    "More" : "Mehr",
    "Edit" : "Bearbeiten",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "Teile mit Benutzern und Gruppen",
    "can edit" : "kann bearbeiten",
    "group" : "Gruppe",
    "New Calendar" : "Neuer Kalender",
    "Subscriptions" : "Abonnements",
    "New Subscription" : "neues Abonnement",
    "Url" : "Url",
    "Edit event" : "Veranstaltung bearbeiten",
    "Delete Event" : "Veranstaltung löschen",
    "Save Event" : "Veranstaltung speichern",
    "Time" : "Zeit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Wiederholen",
    "times every" : "mal pro",
    "Add" : "Hinzufügen",
    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
    "Please add your email address in the personal settings in order to add attendees." : "Bitte geben Sie Ihre E-Mail-Adresse in den Einstellungen an um Teilnehmer hinzuzufügen.",
    "from" : "von",
    "to" : "an",
    "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Termins wird noch nicht unterstützt.",
    "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Updates hinzugefügt.",
    "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
    "Repeat every ..." : "Wiederhole immer ...",
    "end repeat ..." : "Wiederholung beenden ...",
    "times" : "Zeiten",
    "Import Calendars" : "Kalender importieren",
    "Import canceled" : "Import abgebrochen",
    "Analyzing calendar" : "Kalender analysieren",
    "The file contains objects incompatible with the selected calendar" : "Die Datei enthält Objekte, die nicht mit dem ausgewählten Kalender kompatibel sind",
    "New calendar" : "Neuer Kalender",
    "Import scheduled" : "Import geplant",
    "Settings" : "Einstellungen",
    "Import calendar" : "Kalender importieren",
    "No Calendars selected for import" : "Es wurde keine Kalenderdatei für den Import ausgewählt",
    "Primary CalDAV address" : "Primäre CalDAV-Adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-Adresse"
},
"nplurals=2; plural=(n != 1);");
